@@ -1,4 +1,4 @@
-""" Functions for deteriming colors accoriding to some rule.
+""" Functions for determining colors accoriding to some rule.
 """
 
 
@@ -19,7 +19,7 @@ def color_fn(func):
 
 
 @color_fn
-def positive_negative(value):
+def positive_negative(value, baseline=0):
     """ Return positive/negative color based on a value being
     above/below 0.
     """
@@ -36,9 +36,9 @@ def positive_negative(value):
 
 
 @color_fn
-def warm_cold(value):
+def warm_cold(value, baseline=0):
     """ Return warm/cold color based on a value being
-    above/below 0.
+    above/below a baseline.
     """
     if value is None:
         color_name = "neutral"
